==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GeographicSymbolSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningScatterStyleEventArgsDescriptionMetadata } from "./AssigningScatterStyleEventArgsDescriptionMetadata";
import { AssigningScatterMarkerStyleEventArgsDescriptionMetadata } from "./AssigningScatterMarkerStyleEventArgsDescriptionMetadata";
import { GeographicMarkerSeriesDescriptionMetadata } from "./GeographicMarkerSeriesDescriptionMetadata";
import { GeographicSymbolSeriesDescription } from "./GeographicSymbolSeriesDescription";
/**
 * @hidden
 */
var GeographicSymbolSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicSymbolSeriesDescriptionMetadata, _super);
    function GeographicSymbolSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicSymbolSeriesDescriptionMetadata.b = function (a) {
        if (GeographicSymbolSeriesDescriptionMetadata.a == null) {
            GeographicSymbolSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicSymbolSeriesDescriptionMetadata.c(GeographicSymbolSeriesDescriptionMetadata.a);
        }
        if (a.g(GeographicSymbolSeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(GeographicSymbolSeriesDescriptionMetadata.a);
        AssigningScatterStyleEventArgsDescriptionMetadata.d(a);
        AssigningScatterMarkerStyleEventArgsDescriptionMetadata.d(a);
    };
    GeographicSymbolSeriesDescriptionMetadata.c = function (a) {
        GeographicMarkerSeriesDescriptionMetadata.c(a);
        a.item("LatitudeMemberPath", "String");
        a.item("LongitudeMemberPath", "String");
        a.item("MarkerCollisionAvoidance", "ExportedType:string:CollisionAvoidanceType");
        a.item("MarkerCollisionAvoidance@names", "None;Omit;Fade;OmitAndShift;FadeAndShift");
        a.item("IsCustomScatterStyleAllowed", "Boolean");
        a.item("IsCustomScatterMarkerStyleAllowed", "Boolean");
        a.item("ItemSearchMode", "ExportedType:string:ScatterItemSearchMode");
        a.item("ItemSearchMode@names", "Auto;ClosestVisiblePoint;ClosestPoint;ClosestVisiblePointOnClosestLine;ClosestPointOnClosestLine;None");
        a.item("ItemSearchThreshold", "Number:int");
        a.item("AssigningScatterStyleRef", "EventRef::assigningScatterStyle");
        a.item("AssigningScatterMarkerStyleRef", "EventRef::assigningScatterMarkerStyle");
    };
    GeographicSymbolSeriesDescriptionMetadata.d = function (a) {
        GeographicSymbolSeriesDescriptionMetadata.b(a);
        a.u("GeographicSymbolSeries", function () { return new GeographicSymbolSeriesDescription(); });
        a.t("GeographicSymbolSeries", GeographicSymbolSeriesDescriptionMetadata.a);
    };
    GeographicSymbolSeriesDescriptionMetadata.$t = markType(GeographicSymbolSeriesDescriptionMetadata, 'GeographicSymbolSeriesDescriptionMetadata');
    GeographicSymbolSeriesDescriptionMetadata.a = null;
    return GeographicSymbolSeriesDescriptionMetadata;
}(Base));
export { GeographicSymbolSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GeographicSymbolSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningScatterStyleEventArgsDescriptionMetadata } from "./AssigningScatterStyleEventArgsDescriptionMetadata";
import { AssigningScatterMarkerStyleEventArgsDescriptionMetadata } from "./AssigningScatterMarkerStyleEventArgsDescriptionMetadata";
import { GeographicMarkerSeriesDescriptionMetadata } from "./GeographicMarkerSeriesDescriptionMetadata";
import { GeographicSymbolSeriesDescription } from "./GeographicSymbolSeriesDescription";
/**
 * @hidden
 */
var GeographicSymbolSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicSymbolSeriesDescriptionMetadata, _super);
    function GeographicSymbolSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicSymbolSeriesDescriptionMetadata.b = function (a) {
        if (GeographicSymbolSeriesDescriptionMetadata.a == null) {
            GeographicSymbolSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicSymbolSeriesDescriptionMetadata.c(GeographicSymbolSeriesDescriptionMetadata.a);
        }
        if (a.j(GeographicSymbolSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(GeographicSymbolSeriesDescriptionMetadata.a);
        AssigningScatterStyleEventArgsDescriptionMetadata.d(a);
        AssigningScatterMarkerStyleEventArgsDescriptionMetadata.d(a);
    };
    GeographicSymbolSeriesDescriptionMetadata.c = function (a) {
        GeographicMarkerSeriesDescriptionMetadata.c(a);
        a.item("LatitudeMemberPath", "String");
        a.item("LongitudeMemberPath", "String");
        a.item("MarkerCollisionAvoidance", "ExportedType:string:CollisionAvoidanceType");
        a.item("MarkerCollisionAvoidance@names", "None;Omit;Fade;OmitAndShift;FadeAndShift");
        a.item("IsCustomScatterStyleAllowed", "Boolean");
        a.item("IsCustomScatterMarkerStyleAllowed", "Boolean");
        a.item("ItemSearchMode", "ExportedType:string:ScatterItemSearchMode");
        a.item("ItemSearchMode@names", "Auto;ClosestVisiblePoint;ClosestPoint;ClosestVisiblePointOnClosestLine;ClosestPointOnClosestLine;None");
        a.item("ItemSearchThreshold", "Number:int");
        a.item("AssigningScatterStyleRef", "EventRef::assigningScatterStyle");
        a.item("AssigningScatterMarkerStyleRef", "EventRef::assigningScatterMarkerStyle");
    };
    GeographicSymbolSeriesDescriptionMetadata.d = function (a) {
        GeographicSymbolSeriesDescriptionMetadata.b(a);
        a.aa("GeographicSymbolSeries", function () { return new GeographicSymbolSeriesDescription(); });
        a.z("GeographicSymbolSeries", GeographicSymbolSeriesDescriptionMetadata.a);
    };
    GeographicSymbolSeriesDescriptionMetadata.$t = markType(GeographicSymbolSeriesDescriptionMetadata, 'GeographicSymbolSeriesDescriptionMetadata');
    GeographicSymbolSeriesDescriptionMetadata.a = null;
    return GeographicSymbolSeriesDescriptionMetadata;
}(Base));
export { GeographicSymbolSeriesDescriptionMetadata };
